@@ -1,6 +1,6 @@
 /* query-fields-editor.c
  *
- * Copyright (C) 2004 - 2005 Vivien Malerba
+ * Copyright (C) 2004 - 2006 Vivien Malerba
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -20,7 +20,7 @@
 
 #include "query-fields-editor.h"
 #include "query-fields-menu.h"
-
+#include <glib/gi18n-lib.h>
 
 static void query_fields_editor_class_init (QueryFieldsEditorClass * class);
 static void query_fields_editor_init (QueryFieldsEditor * wid);
@@ -29,7 +29,7 @@ static void query_fields_editor_dispose (GObject   * object);
 
 struct _QueryFieldsEditorPriv
 {
-	GnomeDbQuery *query;
+	GdaQuery     *query;
 	
 	GtkTreeModel *model;
 	GtkTreeView  *view;
@@ -79,12 +79,12 @@ query_fields_editor_class_init (QueryFieldsEditorClass * class)
 enum {
 	COLUMN_FIELD_PTR,   /* pointer to GnomeDbQField obj */
 	COLUMN_FIELD_TXT,
-	COLUMN_FIELD_EDIT,  /* TRUE if field text can be edited: for GnomeDbQfValue, GnomeDbQfFunc, etc */
+	COLUMN_FIELD_EDIT,  /* TRUE if field text can be edited: for GdaQueryFieldValue, GdaQueryFieldFunc, etc */
 	COLUMN_SHOWN,       /* TRUE if field visible && not internal */
 	COLUMN_ALIAS,
 	COLUMN_FILTER,
 	COLUMN_FILTER_ENABLE, /* TRUE if the WHERE condition is composed of AND'ed individual conditions */
-	COLUMN_FILTER_COND,   /* GnomeDbCondition pointer if COLUMN_FILTER does have some text */
+	COLUMN_FILTER_COND,   /* GdaQueryCondition pointer if COLUMN_FILTER does have some text */
 	COLUMN_ORDER_NUMBER, /* -1 if not ordered */
 	COLUMN_ORDER_ENABLE, /* TRUE if field is in the ORDER BY */
 	COLUMN_ORDER_ASC,
@@ -116,24 +116,24 @@ query_fields_editor_init (QueryFieldsEditor * wid)
 static void query_fields_editor_initialize (QueryFieldsEditor *mgsel);
 
 
-static void query_nullified_cb (GnomeDbQuery *query, QueryFieldsEditor *mgsel);
-static void query_changed_cb (GnomeDbQuery *query, QueryFieldsEditor *fedit);
+static void query_destroyed_cb (GdaQuery *query, QueryFieldsEditor *mgsel);
+static void query_changed_cb (GdaQuery *query, QueryFieldsEditor *fedit);
 
 /**
  * query_fields_editor_new
- * @query: a #GnomeDbQuery object
+ * @query: a #GdaQuery object
  *
  * Creates a new #QueryFieldsEditor widget.
  *
  * Returns: the new widget
  */
 GtkWidget *
-query_fields_editor_new (GnomeDbQuery *query, guint mode)
+query_fields_editor_new (GdaQuery *query, guint mode)
 {
 	GObject    *obj;
 	QueryFieldsEditor *fedit;
 
-	g_return_val_if_fail (query && IS_GNOME_DB_QUERY (query), NULL);
+	g_return_val_if_fail (query && GDA_IS_QUERY (query), NULL);
 		
 	obj = g_object_new (QUERY_FIELDS_EDITOR_TYPE, NULL);
 	fedit = QUERY_FIELDS_EDITOR (obj);
@@ -141,8 +141,8 @@ query_fields_editor_new (GnomeDbQuery *query, guint mode)
 	fedit->priv->query = query;
 	fedit->priv->mode = mode;
 
-	gnome_db_base_connect_nullify (fedit->priv->query,
-				 G_CALLBACK (query_nullified_cb), fedit);
+	gda_object_connect_destroy (fedit->priv->query,
+				 G_CALLBACK (query_destroyed_cb), fedit);
 	g_signal_connect (G_OBJECT (fedit->priv->query), "changed",
 			  G_CALLBACK (query_changed_cb), fedit);
 	
@@ -152,7 +152,7 @@ query_fields_editor_new (GnomeDbQuery *query, guint mode)
 }
 
 static void
-query_nullified_cb (GnomeDbQuery *query, QueryFieldsEditor *mgsel)
+query_destroyed_cb (GdaQuery *query, QueryFieldsEditor *mgsel)
 {
 	gtk_widget_destroy (GTK_WIDGET (mgsel));
 }
@@ -167,10 +167,10 @@ query_fields_editor_dispose (GObject *object)
 	fedit = QUERY_FIELDS_EDITOR (object);
 
 	if (fedit->priv) {
-		/* Weak unref the GnomeDbQuery if necessary */
+		/* Weak unref the GdaQuery if necessary */
 		if (fedit->priv->query) {
 			g_signal_handlers_disconnect_by_func (G_OBJECT (fedit->priv->query),
-							      G_CALLBACK (query_nullified_cb), fedit);
+							      G_CALLBACK (query_destroyed_cb), fedit);
 			g_signal_handlers_disconnect_by_func (G_OBJECT (fedit->priv->query),
 							      G_CALLBACK (query_changed_cb), fedit);
 		}
@@ -368,15 +368,15 @@ query_fields_editor_initialize (QueryFieldsEditor *fedit)
 }
 
 /*
- * Fetch the GnomeDbQfield held at row described by @tree_path. if @iter is not NULL, then sets
+ * Fetch the GdaQueryField held at row described by @tree_path. if @iter is not NULL, then sets
  * it to represent the corresponding row
  */
-static GnomeDbQfield *
+static GdaQueryField *
 model_get_field_from_path (GtkTreeModel *model, GtkTreeIter *iter, const gchar *tree_path)
 {
 	GtkTreeIter tmpiter;
 	GtkTreePath *path;
-	GnomeDbQfield *field = NULL;	
+	GdaQueryField *field = NULL;	
 
 	path = gtk_tree_path_new_from_string (tree_path);
 	if (gtk_tree_model_get_iter (model, &tmpiter, path)) {
@@ -392,9 +392,9 @@ model_get_field_from_path (GtkTreeModel *model, GtkTreeIter *iter, const gchar *
 /*
  * Sets @iter to point to the row representing @field
  */
-static gboolean get_iter_for_field (QueryFieldsEditor *fedit, GtkTreeIter *iter, GnomeDbField *field)
+static gboolean get_iter_for_field (QueryFieldsEditor *fedit, GtkTreeIter *iter, GdaEntityField *field)
 {
-	GnomeDbField *tmpfield;
+	GdaEntityField *tmpfield;
 
 	g_return_val_if_fail (iter, FALSE);
 	g_return_val_if_fail (field, FALSE);
@@ -420,17 +420,20 @@ static void
 renderer_field_txt_edited_cb (GtkCellRendererText *renderer, 
 			      gchar *tree_path, gchar *new_text, QueryFieldsEditor *fedit)
 {
-	GnomeDbQfield *field;
+	GdaQueryField *field;
 
 	field = model_get_field_from_path (fedit->priv->model, NULL, tree_path);
-	if (IS_GNOME_DB_QF_VALUE (field)) {
-		GdaValue *value;
-		GnomeDbServerDataType *dtype = gnome_db_qf_value_get_server_data_type (GNOME_DB_QF_VALUE (field));
-		GnomeDbDataHandler *dh = gnome_db_server_data_type_get_handler (dtype);
-		value = gnome_db_data_handler_get_value_from_sql (dh, new_text, 
-							    gnome_db_qf_value_get_value_type (GNOME_DB_QF_VALUE (field)));
+	if (GDA_IS_QUERY_FIELD_VALUE (field)) {
+		GValue *value;
+		GType gtype;
+		GdaDataHandler *dh;
+
+		g_object_get (G_OBJECT (field), "gda-type", &gtype, NULL);
+		dh = gda_dict_get_default_handler (gda_object_get_dict ((GdaObject *) field), gtype);
+		value = gda_data_handler_get_value_from_sql (dh, new_text, 
+							     gda_query_field_value_get_g_type (GDA_QUERY_FIELD_VALUE (field)));
 		if (value) {
-			gnome_db_qf_value_set_value (GNOME_DB_QF_VALUE (field), value);
+			gda_query_field_value_set_value (GDA_QUERY_FIELD_VALUE (field), value);
 			gda_value_free (value);
 		}
 	}
@@ -440,28 +443,28 @@ static void
 renderer_field_shown_toggled_cb (GtkCellRendererToggle *renderer,
 				 gchar *tree_path, QueryFieldsEditor *fedit)
 {
-	GnomeDbQfield *field;
+	GdaQueryField *field;
 
 	field = model_get_field_from_path (fedit->priv->model, NULL, tree_path);
-	gnome_db_qfield_set_visible (field, !gtk_cell_renderer_toggle_get_active (renderer));
+	gda_query_field_set_visible (field, !gtk_cell_renderer_toggle_get_active (renderer));
 }
 
 static void
 renderer_field_alias_edited_cb (GtkCellRendererText *renderer, 
 				gchar *tree_path, gchar *new_text, QueryFieldsEditor *fedit)
 {
-	GnomeDbQfield *field;
+	GdaQueryField *field;
 
 	field = model_get_field_from_path (fedit->priv->model, NULL, tree_path);
-	gnome_db_qfield_set_alias (field, new_text);
+	gda_query_field_set_alias (field, new_text);
 }
 
 static void
 renderer_field_filter_edited_cb (GtkCellRendererText *renderer, 
 				 gchar *tree_path, gchar *new_text, QueryFieldsEditor *fedit)
 {
-	GnomeDbQfield *field;
-	GnomeDbCondition *newcond, *cond;
+	GdaQueryField *field;
+	GdaQueryCondition *newcond, *cond;
 	GtkTreeIter iter;
 
 	field = model_get_field_from_path (fedit->priv->model, &iter, tree_path);
@@ -470,14 +473,14 @@ renderer_field_filter_edited_cb (GtkCellRendererText *renderer,
 	if (new_text && *new_text) {
 		GError *error = NULL;
 
-		newcond = (GnomeDbCondition *) gnome_db_condition_new_from_sql (fedit->priv->query, new_text, NULL, &error);
+		newcond = gda_query_condition_new_from_sql (fedit->priv->query, new_text, NULL, &error);
 		if (!newcond) {
 			gchar *sql;
-			sql = gnome_db_renderer_render_as_sql (GNOME_DB_RENDERER (field), NULL, 0, NULL);
+			sql = gda_renderer_render_as_sql (GDA_RENDERER (field), NULL, 0, NULL);
 			if (sql) {
 				gchar *text = g_strdup_printf ("%s %s", sql, new_text);
 				g_free (sql);
-				newcond = (GnomeDbCondition *) gnome_db_condition_new_from_sql (fedit->priv->query, text, NULL, NULL);
+				newcond = gda_query_condition_new_from_sql (fedit->priv->query, text, NULL, NULL);
 				g_free (text);
 			}
 		}
@@ -515,27 +518,27 @@ renderer_field_filter_edited_cb (GtkCellRendererText *renderer,
 	if (newcond) {
 		if (cond) {
 			/* there was a previous condition */
-			GnomeDbCondition *parent = gnome_db_condition_get_parent (cond);
+			GdaQueryCondition *parent = gda_query_condition_get_parent (cond);
 			if (parent) {
 				GHashTable *repl;
 
 				repl = g_hash_table_new (NULL, NULL);
 				g_hash_table_insert (repl, cond, newcond);
-				gnome_db_referer_replace_refs (GNOME_DB_REFERER (parent), repl);
+				gda_referer_replace_refs (GDA_REFERER (parent), repl);
 				g_hash_table_destroy (repl);
 			}
 			else 
-				gnome_db_query_set_condition (fedit->priv->query, newcond);
+				gda_query_set_condition (fedit->priv->query, newcond);
 		}
 		else 
 			/* 'append' with an AND the new condition to the already existing one */
-			gnome_db_query_append_condition (fedit->priv->query, newcond, TRUE);
+			gda_query_append_condition (fedit->priv->query, newcond, TRUE);
 
 		g_object_unref (newcond);
 	}
 	else {
 		if (cond) 
-			gnome_db_base_nullify (GNOME_DB_BASE (cond));
+			gda_object_destroy (GDA_OBJECT (cond));
 	}
 }
 
@@ -543,19 +546,19 @@ static void
 renderer_field_orderno_edited_cb  (GtkCellRendererText *renderer, 
 				   gchar *tree_path, gchar *new_text, QueryFieldsEditor *fedit)
 {
-	GnomeDbQfield *field;
+	GdaQueryField *field;
 	gint order;
 
 	field = model_get_field_from_path (fedit->priv->model, NULL, tree_path);
 	order = atoi (new_text);
 	if (order > 0) {
 		gboolean asc;
-		if (gnome_db_query_get_order_by_field (fedit->priv->query, field, &asc) < 0)
+		if (gda_query_get_order_by_field (fedit->priv->query, field, &asc) < 0)
 			asc = TRUE;
-		gnome_db_query_set_order_by_field (fedit->priv->query, field, order - 1, asc);
+		gda_query_set_order_by_field (fedit->priv->query, field, order - 1, asc);
 	}
 	else
-		gnome_db_query_set_order_by_field (fedit->priv->query, field, -1, TRUE);
+		gda_query_set_order_by_field (fedit->priv->query, field, -1, TRUE);
 		
 }
 
@@ -563,13 +566,13 @@ static void
 renderer_field_orderty_edited_cb  (GtkCellRendererText *renderer, 
 				   gchar *tree_path, gchar *new_text, QueryFieldsEditor *fedit)
 {
-	GnomeDbQfield *field;
+	GdaQueryField *field;
 	gint order;
 
 	field = model_get_field_from_path (fedit->priv->model, NULL, tree_path);
 
-	order = gnome_db_query_get_order_by_field (fedit->priv->query, field, NULL);
-	gnome_db_query_set_order_by_field (fedit->priv->query, field, order, 
+	order = gda_query_get_order_by_field (fedit->priv->query, field, NULL);
+	gda_query_set_order_by_field (fedit->priv->query, field, order, 
 				     new_text && ((*new_text == 'A') || (*new_text == 'a')));
 }
 
@@ -579,18 +582,18 @@ field_selection_changed_cb (GtkTreeSelection *selection, QueryFieldsEditor *fedi
 	gint pos = 0;
 	gboolean has_sel;
 	GtkTreeIter iter;
-	GnomeDbField *ofield = NULL;
+	GdaEntityField *ofield = NULL;
 
 	if (!fedit->priv->del_button)
 		return;
 
 	has_sel = gtk_tree_selection_get_selected (selection, NULL, &iter);
 	if (has_sel) {
-		GnomeDbField *field;
+		GdaEntityField *field;
 
 		gtk_tree_model_get (fedit->priv->model, &iter, COLUMN_FIELD_PTR, &field, -1);
-		pos = gnome_db_entity_get_field_index (GNOME_DB_ENTITY (fedit->priv->query), field);
-		ofield = gnome_db_entity_get_field_by_index (GNOME_DB_ENTITY (fedit->priv->query), pos + 1);
+		pos = gda_entity_get_field_index (GDA_ENTITY (fedit->priv->query), field);
+		ofield = gda_entity_get_field_by_index (GDA_ENTITY (fedit->priv->query), pos + 1);
 	}
 
 	gtk_widget_set_sensitive (fedit->priv->del_button, has_sel);
@@ -606,10 +609,10 @@ action_drop_field_cb (GtkButton *button, QueryFieldsEditor *fedit)
 
 	select = gtk_tree_view_get_selection (GTK_TREE_VIEW (fedit->priv->view));
 	if (gtk_tree_selection_get_selected (select, NULL, &iter)) {
-		GnomeDbQfield *field;
+		GdaQueryField *field;
 
 		gtk_tree_model_get (fedit->priv->model, &iter, COLUMN_FIELD_PTR, &field, -1);
-		gnome_db_entity_remove_field (GNOME_DB_ENTITY (fedit->priv->query), GNOME_DB_FIELD (field));
+		gda_entity_remove_field (GDA_ENTITY (fedit->priv->query), GDA_ENTITY_FIELD (field));
 	}
 }
 
@@ -621,15 +624,15 @@ action_up_field_cb (GtkButton *button, QueryFieldsEditor *fedit)
 
 	select = gtk_tree_view_get_selection (GTK_TREE_VIEW (fedit->priv->view));
 	if (gtk_tree_selection_get_selected (select, NULL, &iter)) {
-		GnomeDbField *field;
+		GdaEntityField *field;
 		gint pos;
 
 		gtk_tree_model_get (fedit->priv->model, &iter, COLUMN_FIELD_PTR, &field, -1);
-		pos = gnome_db_entity_get_field_index (GNOME_DB_ENTITY (fedit->priv->query), field);
+		pos = gda_entity_get_field_index (GDA_ENTITY (fedit->priv->query), field);
 		if (pos > 0) {
-			GnomeDbField *ofield;
-			ofield = gnome_db_entity_get_field_by_index (GNOME_DB_ENTITY (fedit->priv->query), pos - 1);
-			gnome_db_entity_swap_fields (GNOME_DB_ENTITY (fedit->priv->query), field, ofield);
+			GdaEntityField *ofield;
+			ofield = gda_entity_get_field_by_index (GDA_ENTITY (fedit->priv->query), pos - 1);
+			gda_entity_swap_fields (GDA_ENTITY (fedit->priv->query), field, ofield);
 
 			if (get_iter_for_field (fedit, &iter, field))
 				gtk_tree_selection_select_iter (select, &iter);
@@ -645,14 +648,14 @@ action_down_field_cb (GtkButton *button, QueryFieldsEditor *fedit)
 
 	select = gtk_tree_view_get_selection (GTK_TREE_VIEW (fedit->priv->view));
 	if (gtk_tree_selection_get_selected (select, NULL, &iter)) {
-		GnomeDbField *field, *ofield;
+		GdaEntityField *field, *ofield;
 		gint pos;
 
 		gtk_tree_model_get (fedit->priv->model, &iter, COLUMN_FIELD_PTR, &field, -1);
-		pos = gnome_db_entity_get_field_index (GNOME_DB_ENTITY (fedit->priv->query), field);
-		ofield = gnome_db_entity_get_field_by_index (GNOME_DB_ENTITY (fedit->priv->query), pos + 1);
+		pos = gda_entity_get_field_index (GDA_ENTITY (fedit->priv->query), field);
+		ofield = gda_entity_get_field_by_index (GDA_ENTITY (fedit->priv->query), pos + 1);
 		if (ofield) {
-			gnome_db_entity_swap_fields (GNOME_DB_ENTITY (fedit->priv->query), field, ofield);
+			gda_entity_swap_fields (GDA_ENTITY (fedit->priv->query), field, ofield);
 
 			if (get_iter_for_field (fedit, &iter, field))
 				gtk_tree_selection_select_iter (select, &iter);
@@ -666,7 +669,7 @@ static GSList *compute_fields_to_display (QueryFieldsEditor *fedit);
  * (re)-write all the rows of the model with the fields which do qualify to be displayed
  */
 static void
-query_changed_cb (GnomeDbQuery *query, QueryFieldsEditor *fedit)
+query_changed_cb (GdaQuery *query, QueryFieldsEditor *fedit)
 {
 	GSList *list, *fields;
 	GtkTreeIter iter;
@@ -676,11 +679,11 @@ query_changed_cb (GnomeDbQuery *query, QueryFieldsEditor *fedit)
 	fields = compute_fields_to_display (fedit);
 	list = fields;
 	while (list) {
-		GnomeDbQfield *field = GNOME_DB_QFIELD (list->data);
+		GdaQueryField *field = GDA_QUERY_FIELD (list->data);
 		gchar *sql, *order_str = NULL, *asc_str = NULL;
 		gint order;
 		gboolean asc = TRUE;
-		GnomeDbCondition *cond;
+		GdaQueryCondition *cond;
 		gchar *cond_sql = NULL;
 		
 		/* fetch a new iter */
@@ -697,8 +700,8 @@ query_changed_cb (GnomeDbQuery *query, QueryFieldsEditor *fedit)
 		}
 		
 		/* modify the model at iter */
-		sql = gnome_db_renderer_render_as_sql (GNOME_DB_RENDERER (field), NULL, 0, NULL);
-		order = gnome_db_query_get_order_by_field (fedit->priv->query, field, &asc);
+		sql = gda_renderer_render_as_sql (GDA_RENDERER (field), NULL, 0, NULL);
+		order = gda_query_get_order_by_field (fedit->priv->query, field, &asc);
 		if (order >= 0) {
 			order_str = g_strdup_printf ("%d", order + 1);
 			asc_str = asc ? "ASC" : "DESC";
@@ -706,15 +709,15 @@ query_changed_cb (GnomeDbQuery *query, QueryFieldsEditor *fedit)
 		cond = g_object_get_data (G_OBJECT (field), "qf_filter_cond");
 		g_object_set_data (G_OBJECT (field), "qf_filter_cond", NULL);
 		if (cond) 
-			cond_sql = gnome_db_renderer_render_as_sql (GNOME_DB_RENDERER (cond), NULL, 
-								    GNOME_DB_RENDERER_EXTRA_VAL_ATTRS,
+			cond_sql = gda_renderer_render_as_sql (GDA_RENDERER (cond), NULL, 
+								    GDA_RENDERER_EXTRA_VAL_ATTRS,
 								    NULL);
 		gtk_list_store_set (GTK_LIST_STORE (model), &iter,
 				    COLUMN_FIELD_PTR, field,
-				    COLUMN_FIELD_TXT, sql ? sql : gnome_db_base_get_name (GNOME_DB_BASE (field)),
-				    COLUMN_FIELD_EDIT, IS_GNOME_DB_QF_VALUE (field),
-				    COLUMN_SHOWN, gnome_db_qfield_is_visible (field),
-				    COLUMN_ALIAS, gnome_db_qfield_get_alias (field),
+				    COLUMN_FIELD_TXT, sql ? sql : gda_object_get_name (GDA_OBJECT (field)),
+				    COLUMN_FIELD_EDIT, GDA_IS_QUERY_FIELD_VALUE (field),
+				    COLUMN_SHOWN, gda_query_field_is_visible (field),
+				    COLUMN_ALIAS, gda_query_field_get_alias (field),
 				    COLUMN_ORDER_NUMBER, order_str,
 				    COLUMN_ORDER_ENABLE, (order >= 0) ? TRUE : FALSE,
 				    COLUMN_ORDER_ASC, asc_str,
@@ -749,27 +752,27 @@ compute_fields_to_display (QueryFieldsEditor *fedit)
 	GSList *list, *fields;
 	GSList *retval = NULL;
 	GSList *main_conds = NULL;
-	GnomeDbCondition *cond;
+	GdaQueryCondition *cond;
 	
-	cond = gnome_db_query_get_condition (fedit->priv->query);
+	cond = gda_query_get_condition (fedit->priv->query);
 	if (cond)
-		main_conds = gnome_db_condition_get_main_conditions (cond);
+		main_conds = gda_query_condition_get_main_conditions (cond);
 	
 	/* FIXME: add the fields which are GROUPed BY, and the ones in HAVING condition */	
 	/* analyse all query's fields */
-	fields = gnome_db_query_get_all_fields (fedit->priv->query);
+	fields = gda_query_get_all_fields (fedit->priv->query);
 	list = fields;
 	while (list) {
-		GnomeDbQfield *field = GNOME_DB_QFIELD (list->data);
+		GdaQueryField *field = GDA_QUERY_FIELD (list->data);
 		gboolean to_include = FALSE;
 		GSList *clist;
 
 		/* fields as LEFT op of a main condition are always shown */
 		clist = main_conds;
 		while (clist && !to_include) {
-			cond = GNOME_DB_CONDITION (clist->data);
-			if (gnome_db_condition_is_leaf (cond) && 
-			    (gnome_db_condition_leaf_get_operator (cond, GNOME_DB_CONDITION_OP_LEFT) == field)) {
+			cond = GDA_QUERY_CONDITION (clist->data);
+			if (gda_query_condition_is_leaf (cond) && 
+			    (gda_query_condition_leaf_get_operator (cond, GDA_QUERY_CONDITION_OP_LEFT) == field)) {
 				to_include = TRUE;
 				g_object_set_data (G_OBJECT (field), "qf_filter_cond", cond);
 			}
@@ -782,7 +785,7 @@ compute_fields_to_display (QueryFieldsEditor *fedit)
 		}
 
 		/* fields in ORDER BY are always shows */
-		if (gnome_db_query_get_order_by_field (fedit->priv->query, field, NULL) >= 0) {
+		if (gda_query_get_order_by_field (fedit->priv->query, field, NULL) >= 0) {
 			retval = g_slist_prepend (retval, field);
 			list = g_slist_next (list);
 			continue;
@@ -790,9 +793,9 @@ compute_fields_to_display (QueryFieldsEditor *fedit)
 
 		/* other tests */
 		to_include = TRUE;
-		if (gnome_db_qfield_is_internal (field))
+		if (gda_query_field_is_internal (field))
 			to_include = FALSE;
-		if (to_include && !gnome_db_qfield_is_visible (field))
+		if (to_include && !gda_query_field_is_visible (field))
 			to_include = FALSE;
 		if (to_include)
 			retval = g_slist_prepend (retval, field);
