@@ -1,6 +1,6 @@
 /* query-params-editor.c
  *
- * Copyright (C) 2004 Vivien Malerba
+ * Copyright (C) 2004 - 2006 Vivien Malerba
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -19,7 +19,7 @@
  */
 
 #include "query-params-editor.h"
-
+#include <glib/gi18n-lib.h>
 
 static void query_params_editor_class_init (QueryParamsEditorClass * class);
 static void query_params_editor_init (QueryParamsEditor * wid);
@@ -28,7 +28,7 @@ static void query_params_editor_dispose (GObject   * object);
 
 struct _QueryParamsEditorPriv
 {
-	GnomeDbQuery      *query;
+	GdaQuery      *query;
 	
 	GtkTreeModel *model;
 	GtkTreeView  *view;
@@ -75,9 +75,9 @@ query_params_editor_class_init (QueryParamsEditorClass * class)
 }
 
 enum {
-	COLUMN_PARAM_PTR,   /* pointer to GnomeDbParameter obj */
-	COLUMN_QFVALUE_PTR, /* pointer to GnomeDbQfValue obj if not param */
-	COLUMN_ISPARAM,     /* TRUE if we reference a GnomeDbParameter obj, and FALSE if a GnomeDbQfValue obj */
+	COLUMN_PARAM_PTR,   /* pointer to GdaParameter obj */
+	COLUMN_QFVALUE_PTR, /* pointer to GdaQueryFieldValue obj if not param */
+	COLUMN_ISPARAM,     /* TRUE if we reference a GdaParameter obj, and FALSE if a GdaQueryFieldValue obj */
 	COLUMN_PARAM_NAME,
 	COLUMN_PARAM_VALUE,
 	COLUMN_PARAM_DESCR,
@@ -106,19 +106,19 @@ query_params_editor_init (QueryParamsEditor * wid)
 static void query_params_editor_initialize (QueryParamsEditor *mgsel);
 
 
-static void query_nullified_cb (GnomeDbQuery *query, QueryParamsEditor *mgsel);
-static void query_changed_cb (GnomeDbQuery *query, QueryParamsEditor *pedit);
+static void query_destroyed_cb (GdaQuery *query, QueryParamsEditor *mgsel);
+static void query_changed_cb (GdaQuery *query, QueryParamsEditor *pedit);
 
 /**
  * query_params_editor_new
- * @query: a #GnomeDbQuery object
+ * @query: a #GdaQuery object
  *
  * Creates a new #QueryParamsEditor widget.
  *
  * Returns: the new widget
  */
 GtkWidget *
-query_params_editor_new (GnomeDbQuery *query, guint mode)
+query_params_editor_new (GdaQuery *query, guint mode)
 {
 	GObject    *obj;
 	QueryParamsEditor *pedit;
@@ -137,12 +137,12 @@ query_params_editor_new (GnomeDbQuery *query, guint mode)
 /**
  * query_params_editor_set_query
  * @editor: a #QueryParamsEditor widget
- * @query: a #GnomeDbQuery, or %NULL
+ * @query: a #GdaQuery, or %NULL
  *
- * Sets the #GnomeDbQuery for which @editor will display the parameters
+ * Sets the #GdaQuery for which @editor will display the parameters
  */
 void
-query_params_editor_set_query (QueryParamsEditor *editor, GnomeDbQuery *query)
+query_params_editor_set_query (QueryParamsEditor *editor, GdaQuery *query)
 {
 	g_return_if_fail (editor && IS_QUERY_PARAMS_EDITOR (editor));
 	g_return_if_fail (editor->priv);
@@ -153,7 +153,7 @@ query_params_editor_set_query (QueryParamsEditor *editor, GnomeDbQuery *query)
 	/* OLD one */
 	if (editor->priv->query) {
 		g_signal_handlers_disconnect_by_func (G_OBJECT (editor->priv->query),
-						      G_CALLBACK (query_nullified_cb), editor);
+						      G_CALLBACK (query_destroyed_cb), editor);
 		g_signal_handlers_disconnect_by_func (G_OBJECT (editor->priv->query),
 						      G_CALLBACK (query_changed_cb), editor);
 		editor->priv->query = NULL;
@@ -161,11 +161,11 @@ query_params_editor_set_query (QueryParamsEditor *editor, GnomeDbQuery *query)
 
 	/* new one */
 	if (query) {
-		g_return_if_fail (query && IS_GNOME_DB_QUERY (query));
+		g_return_if_fail (query && GDA_IS_QUERY (query));
 
 		editor->priv->query = query;
-		gnome_db_base_connect_nullify (editor->priv->query,
-					 G_CALLBACK (query_nullified_cb), editor);
+		gda_object_connect_destroy (editor->priv->query,
+					 G_CALLBACK (query_destroyed_cb), editor);
 		g_signal_connect (G_OBJECT (editor->priv->query), "changed",
 				  G_CALLBACK (query_changed_cb), editor);
 
@@ -174,7 +174,7 @@ query_params_editor_set_query (QueryParamsEditor *editor, GnomeDbQuery *query)
 }
 
 static void
-query_nullified_cb (GnomeDbQuery *query, QueryParamsEditor *mgsel)
+query_destroyed_cb (GdaQuery *query, QueryParamsEditor *mgsel)
 {
 	query_params_editor_set_query (mgsel, NULL);
 }
@@ -205,10 +205,10 @@ query_params_editor_dispose (GObject *object)
 		if (pedit->priv->params)
 			params_free (pedit);
 
-		/* Weak unref the GnomeDbQuery if necessary */
+		/* Weak unref the GdaQuery if necessary */
 		if (pedit->priv->query) {
 			g_signal_handlers_disconnect_by_func (G_OBJECT (pedit->priv->query),
-							      G_CALLBACK (query_nullified_cb), pedit);
+							      G_CALLBACK (query_destroyed_cb), pedit);
 			g_signal_handlers_disconnect_by_func (G_OBJECT (pedit->priv->query),
 							      G_CALLBACK (query_changed_cb), pedit);
 		}
@@ -367,8 +367,8 @@ query_params_editor_initialize (QueryParamsEditor *pedit)
 }
 
 /*
- * Fetch a list of GnomeDbQfValue objects which can get their value from the 
- * GnomeDbParameter stored at row described by @tree_path. if @iter is not NULL, then sets
+ * Fetch a list of GdaQueryFieldValue objects which can get their value from the 
+ * GdaParameter stored at row described by @tree_path. if @iter is not NULL, then sets
  * it to represent the corresponding row
  *
  * The returned list must then be free'd
@@ -379,8 +379,8 @@ model_get_value_field_from_path (GtkTreeModel *model, GtkTreeIter *iter, const g
 	GSList *list = NULL;
 	GtkTreeIter tmpiter;
 	GtkTreePath *path;
-	GnomeDbQfield *field = NULL;	
-	GnomeDbParameter *param = NULL;	
+	GdaQueryField *field = NULL;	
+	GdaParameter *param = NULL;	
 
 	path = gtk_tree_path_new_from_string (tree_path);
 	if (gtk_tree_model_get_iter (model, &tmpiter, path)) {
@@ -391,7 +391,7 @@ model_get_value_field_from_path (GtkTreeModel *model, GtkTreeIter *iter, const g
 	gtk_tree_path_free (path);
 
 	if (param) 
-		list = g_slist_copy (gnome_db_parameter_get_dest_fields (GNOME_DB_PARAMETER (param)));
+		list = g_slist_copy (gda_parameter_get_param_users (GDA_PARAMETER (param)));
 	if (field)
 		list = g_slist_append (list, field);
 
@@ -403,15 +403,15 @@ renderer_param_name_edited_cb (GtkCellRendererText *renderer,
 			       gchar *tree_path, gchar *new_text, QueryParamsEditor *pedit)
 {
 	GSList *fields, *list;
-	GnomeDbQfield *field;
+	GdaQueryField *field;
 
 	fields = model_get_value_field_from_path (pedit->priv->model, NULL, tree_path);
 	list = fields;
 	while (list) {
-		field = (GnomeDbQfield *) (list->data);
+		field = (GdaQueryField *) (list->data);
 
-		if (IS_GNOME_DB_QF_VALUE (field)) 
-			gnome_db_base_set_name (GNOME_DB_BASE (field), new_text);
+		if (GDA_IS_QUERY_FIELD_VALUE (field)) 
+			gda_object_set_name (GDA_OBJECT (field), new_text);
 		
 		list = g_slist_next (list);
 	}
@@ -423,21 +423,30 @@ renderer_param_value_edited_cb (GtkCellRendererText *renderer,
 				gchar *tree_path, gchar *new_text, QueryParamsEditor *pedit)
 {
 	GSList *fields, *list;
-	GnomeDbQfield *field;
+	GdaQueryField *field;
 
 	fields = model_get_value_field_from_path (pedit->priv->model, NULL, tree_path);
 	list = fields;
 	while (list) {
-		field = (GnomeDbQfield *) (list->data);
+		field = (GdaQueryField *) (list->data);
 
-		if (IS_GNOME_DB_QF_VALUE (field)) {
-			GdaValue *value;
-			GnomeDbServerDataType *dtype = gnome_db_qf_value_get_server_data_type (GNOME_DB_QF_VALUE (field));
-			GnomeDbDataHandler *dh = gnome_db_server_data_type_get_handler (dtype);
-			value = gnome_db_data_handler_get_value_from_sql (dh, new_text, 
-								    gnome_db_qf_value_get_value_type (GNOME_DB_QF_VALUE (field)));
+		if (GDA_IS_QUERY_FIELD_VALUE (field)) {
+			GValue *value;
+			GType vtype;
+			GdaDataHandler *dh;
+			GdaDictType *dtype;
+
+			dtype = gda_query_field_value_get_dict_type (GDA_QUERY_FIELD_VALUE (field));
+			if (dtype)
+				vtype = gda_dict_type_get_g_type (dtype);
+			else
+				g_object_get (G_OBJECT (field), "gda-type", &vtype, NULL);
+
+			dh = gda_dict_get_default_handler (gda_object_get_dict (GDA_OBJECT (field)), vtype);
+			value = gda_data_handler_get_value_from_sql (dh, new_text, 
+								    gda_query_field_value_get_g_type (GDA_QUERY_FIELD_VALUE (field)));
 			if (value) {
-				gnome_db_qf_value_set_value (GNOME_DB_QF_VALUE (field), value);
+				gda_query_field_value_set_value (GDA_QUERY_FIELD_VALUE (field), value);
 				gda_value_free (value);
 			}
 		}
@@ -452,15 +461,15 @@ renderer_param_descr_edited_cb (GtkCellRendererText *renderer,
 				gchar *tree_path, gchar *new_text, QueryParamsEditor *pedit)
 {
 	GSList *fields, *list;
-	GnomeDbQfield *field;
+	GdaQueryField *field;
 
 	fields = model_get_value_field_from_path (pedit->priv->model, NULL, tree_path);
 	list = fields;
 	while (list) {
-		field = (GnomeDbQfield *) (list->data);
+		field = (GdaQueryField *) (list->data);
 
-		if (IS_GNOME_DB_QF_VALUE (field)) 
-			gnome_db_base_set_description (GNOME_DB_BASE (field), new_text);
+		if (GDA_IS_QUERY_FIELD_VALUE (field)) 
+			gda_object_set_description (GDA_OBJECT (field), new_text);
 		
 		list = g_slist_next (list);
 	}
@@ -471,21 +480,21 @@ static void
 renderer_param_type_edited_cb (GtkCellRendererText *renderer, 
 			       gchar *tree_path, gchar *new_text, QueryParamsEditor *pedit)
 {
-	GnomeDbServerDataType *dtype;
+	GdaDictType *dtype;
 	
-	dtype = gnome_db_server_get_data_type_by_name (gnome_db_dict_get_server (gnome_db_base_get_dict (GNOME_DB_BASE (pedit->priv->query))),
-						 new_text);
+	dtype = gda_dict_get_dict_type_by_name (gda_object_get_dict (GDA_OBJECT (pedit->priv->query)),
+						new_text);
 	if (dtype) {
 		GSList *fields, *list;
-		GnomeDbQfield *field;
+		GdaQueryField *field;
 
 		fields = model_get_value_field_from_path (pedit->priv->model, NULL, tree_path);
 		list = fields;
 		while (list) {
-			field = (GnomeDbQfield *) (list->data);
+			field = (GdaQueryField *) (list->data);
 			
-			if (IS_GNOME_DB_QF_VALUE (field)) 
-				gnome_db_qf_value_set_server_data_type (GNOME_DB_QF_VALUE (field), dtype);
+			if (GDA_IS_QUERY_FIELD_VALUE (field)) 
+				gda_query_field_value_set_dict_type (GDA_QUERY_FIELD_VALUE (field), dtype);
 			
 			list = g_slist_next (list);
 		}
@@ -509,20 +518,20 @@ renderer_param_nullok_toggled_cb (GtkCellRendererToggle *renderer,
 				  gchar *tree_path, QueryParamsEditor *pedit)
 {
 	GSList *fields, *list;
-	GnomeDbQfield *field;
+	GdaQueryField *field;
 
 	fields = model_get_value_field_from_path (pedit->priv->model, NULL, tree_path);
 	list = fields;
 	while (list) {
-		field = (GnomeDbQfield *) (list->data);
+		field = (GdaQueryField *) (list->data);
 
-		if (IS_GNOME_DB_QF_VALUE (field)) {
-			gnome_db_qf_value_set_not_null (GNOME_DB_QF_VALUE (field), 
+		if (GDA_IS_QUERY_FIELD_VALUE (field)) {
+			gda_query_field_value_set_not_null (GDA_QUERY_FIELD_VALUE (field), 
 						  gtk_cell_renderer_toggle_get_active (renderer));
 
-			/* we need to force the "changed" signal emission because GnomeDbQuery normally does
+			/* we need to force the "changed" signal emission because GdaQuery normally does
 			 * not do it in this case */
-			gnome_db_base_changed (GNOME_DB_BASE (pedit->priv->query));
+			gda_object_signal_emit_changed (GDA_OBJECT (pedit->priv->query));
 		}
 		
 		list = g_slist_next (list);
@@ -535,20 +544,20 @@ renderer_param_isparam_toggled_cb (GtkCellRendererToggle *renderer,
 				   gchar *tree_path, QueryParamsEditor *pedit)
 {
 	GSList *fields, *list;
-	GnomeDbQfield *field;
+	GdaQueryField *field;
 
 	fields = model_get_value_field_from_path (pedit->priv->model, NULL, tree_path);
 	list = fields;
 	while (list) {
-		field = (GnomeDbQfield *) (list->data);
+		field = (GdaQueryField *) (list->data);
 
-		if (IS_GNOME_DB_QF_VALUE (field)) {
-			gnome_db_qf_value_set_is_parameter (GNOME_DB_QF_VALUE (field), 
+		if (GDA_IS_QUERY_FIELD_VALUE (field)) {
+			gda_query_field_value_set_is_parameter (GDA_QUERY_FIELD_VALUE (field), 
 						      !gtk_cell_renderer_toggle_get_active (renderer));
 
-			/* we need to force the "changed" signal emission because GnomeDbQuery normally does
+			/* we need to force the "changed" signal emission because GdaQuery normally does
 			 * not do it in this case */
-			gnome_db_base_changed (GNOME_DB_BASE (pedit->priv->query));
+			gda_object_signal_emit_changed (GDA_OBJECT (pedit->priv->query));
 		}
 		
 		list = g_slist_next (list);
@@ -564,7 +573,7 @@ param_selection_changed_cb (GtkTreeSelection *selection, QueryParamsEditor *pedi
 
 	has_sel = gtk_tree_selection_get_selected (selection, NULL, &iter);
 	if (has_sel) {
-		GnomeDbField *field;
+		GdaEntityField *field;
 		
 		gtk_tree_model_get (pedit->priv->model, &iter, COLUMN_PARAM_PTR, &field, -1);
 	}
@@ -575,30 +584,30 @@ param_selection_changed_cb (GtkTreeSelection *selection, QueryParamsEditor *pedi
  * (re)-write all the rows of the model with the params to be displayed
  */
 static void
-query_changed_cb (GnomeDbQuery *query, QueryParamsEditor *pedit)
+query_changed_cb (GdaQuery *query, QueryParamsEditor *pedit)
 {
 	GSList *list, *params;
 	GtkTreeIter iter;
 	GtkTreeModel *model = pedit->priv->model;
 	gboolean iter_valid = FALSE;
-	GnomeDbServer *srv;
+	GdaDict *dict;
        
-	srv = gnome_db_dict_get_server (gnome_db_base_get_dict (GNOME_DB_BASE (pedit->priv->query)));
+	dict = gda_object_get_dict (GDA_OBJECT (pedit->priv->query));
 
 	/*
 	 * Parameters
 	 */
 	if (pedit->priv->params)
 		params_free (pedit);
-	params = gnome_db_entity_get_parameters (GNOME_DB_ENTITY (pedit->priv->query));
+	params = gda_query_get_parameters (pedit->priv->query);
 	pedit->priv->params = params;
 
 	list = params;
 	while (list) {
-		GnomeDbParameter *param = GNOME_DB_PARAMETER (list->data);
+		GdaParameter *param = GDA_PARAMETER (list->data);
 		gchar *valstr;
 		const gchar *typestr;
-		const GdaValue *value;
+		const GValue *value;
 
 		/* fetch a new iter */
 		if (!iter_valid) {
@@ -614,45 +623,44 @@ query_changed_cb (GnomeDbQuery *query, QueryParamsEditor *pedit)
 		}
 
 		/* compute strings */
-		value = gnome_db_parameter_get_value (param);
-		if (value && !gda_value_is_null (value)) {
-			GnomeDbDataHandler *dh = gnome_db_server_get_handler_by_gda (srv,
-									  gda_value_get_type (value));
-			valstr = gnome_db_data_handler_get_sql_from_value (dh, value);
+		value = gda_parameter_get_value (param);
+		if (value && !gda_value_is_null ((GValue *)value)) {
+			GdaDataHandler *dh = gda_dict_get_default_handler (dict, G_VALUE_TYPE ((GValue *)value));
+			valstr = gda_data_handler_get_sql_from_value (dh, value);
 		}
 		else
 			valstr = g_strdup ("");
 
-		typestr = gnome_db_server_data_type_get_sqlname (gnome_db_parameter_get_data_type (param));
+		typestr = g_type_to_string (gda_parameter_get_g_type (param));
 		
 		/* modify the model at iter */
 		gtk_list_store_set (GTK_LIST_STORE (model), &iter,
 				    COLUMN_PARAM_PTR, param,
 				    COLUMN_QFVALUE_PTR, NULL,
 				    COLUMN_ISPARAM, TRUE,
-				    COLUMN_PARAM_NAME, gnome_db_base_get_name (GNOME_DB_BASE (param)),
+				    COLUMN_PARAM_NAME, gda_object_get_name (GDA_OBJECT (param)),
 				    COLUMN_PARAM_VALUE, valstr,
-				    COLUMN_PARAM_DESCR, gnome_db_base_get_description (GNOME_DB_BASE (param)),
+				    COLUMN_PARAM_DESCR, gda_object_get_description (GDA_OBJECT (param)),
 				    COLUMN_PARAM_TYPE, typestr,
-				    COLUMN_PARAM_NULLOK, !gnome_db_parameter_get_not_null (param),
+				    COLUMN_PARAM_NULLOK, !gda_parameter_get_not_null (param),
 				    -1);
 		g_free (valstr);
 		list = g_slist_next (list);
 	}
 
 	/*
-	 * GnomeDbQfValue fields which are not parameters
+	 * GdaQueryFieldValue fields which are not parameters
 	 */
 	if (pedit->priv->mode & QEP_SHOW_ALL_VALUE_FIELDS) {
-		GSList *fields = gnome_db_query_get_all_fields (pedit->priv->query);
+		GSList *fields = gda_query_get_all_fields (pedit->priv->query);
 
 		list = fields;
 		while (list) {
-			if (IS_GNOME_DB_QF_VALUE (list->data) && !gnome_db_qf_value_is_parameter (GNOME_DB_QF_VALUE (list->data))) {
-				GnomeDbQfValue *qfield = GNOME_DB_QF_VALUE (list->data);
+			if (GDA_IS_QUERY_FIELD_VALUE (list->data) && !gda_query_field_value_is_parameter (GDA_QUERY_FIELD_VALUE (list->data))) {
+				GdaQueryFieldValue *qfield = GDA_QUERY_FIELD_VALUE (list->data);
 				gchar *valstr;
 				const gchar *typestr;
-				const GdaValue *value;
+				const GValue *value;
 
 				/* fetch a new iter */
 				if (!iter_valid) {
@@ -668,25 +676,25 @@ query_changed_cb (GnomeDbQuery *query, QueryParamsEditor *pedit)
 				}
 
 				/* compute strings */
-				value = gnome_db_qf_value_get_value (qfield);
-				if (value && !gda_value_is_null (value)) {
-					GnomeDbDataHandler *dh = gnome_db_server_get_handler_by_gda (srv,
-											  gda_value_get_type (value));
-					valstr = gnome_db_data_handler_get_sql_from_value (dh, value);
+				value = gda_query_field_value_get_value (qfield);
+				if (value && !gda_value_is_null ((GValue *)value)) {
+					GdaDataHandler *dh = gda_dict_get_default_handler (dict,
+										  G_VALUE_TYPE ((GValue *)value));
+					valstr = gda_data_handler_get_sql_from_value (dh, value);
 				}
 				else
 					valstr = g_strdup ("");
 				
-				typestr = gnome_db_server_data_type_get_sqlname (gnome_db_qf_value_get_server_data_type (qfield));
+				typestr = gda_dict_type_get_sqlname (gda_query_field_value_get_dict_type (qfield));
 				gtk_list_store_set (GTK_LIST_STORE (model), &iter,
 						    COLUMN_PARAM_PTR, NULL,
 						    COLUMN_QFVALUE_PTR, qfield,
 						    COLUMN_ISPARAM, FALSE,
-						    COLUMN_PARAM_NAME, gnome_db_base_get_name (GNOME_DB_BASE (qfield)),
+						    COLUMN_PARAM_NAME, gda_object_get_name (GDA_OBJECT (qfield)),
 						    COLUMN_PARAM_VALUE, valstr,
-						    COLUMN_PARAM_DESCR, gnome_db_base_get_description (GNOME_DB_BASE (qfield)),
+						    COLUMN_PARAM_DESCR, gda_object_get_description (GDA_OBJECT (qfield)),
 						    COLUMN_PARAM_TYPE, typestr,
-						    COLUMN_PARAM_NULLOK, !gnome_db_qf_value_get_not_null (qfield),
+						    COLUMN_PARAM_NULLOK, !gda_query_field_value_get_not_null (qfield),
 						    -1);
 				g_free (valstr);
 			}
